YOU ARE HERE: HOME > COURT ACTIONS > OPINIONS > SEPTEMBER 2011 TERM |
> | Opinions: September 2011 Term of Court September 1, 2011 - August 31, 2012 Last updated May 16, 2012
> CASE NAME (reverse order) | DOCKET # (reverse order) | OPINION DATE (reverse order) | MJ CITATION (reverse order)
> U.S. v. Barberi | 11-0462/AR (PDF) | May 15, 2012 |
> U.S. v. Ignacio | 12-0202/NA (PDF) | May 10, 2012 | 71 MJ 125
> U.S. v. Dease | 12-6001/AF (PDF) | May 1, 2012 | 71 MJ 116
> U.S. v. Hayes | 12-0090/AF (PDF) | May 1, 2012 | 71 MJ 112
> U.S. v. Nash | 11-5005/MC (PDF) | Apr 13, 2012 | 71 MJ 83
> U.S. v. McClain | 12-0099/AR (PDF) | Apr 10, 2012 | 71 MJ 80
> U.S. v. Nealy | 11-0615/AR (PDF) | Mar 30, 2012 | 71 MJ 73
> U.S. v. Stanley | 11-0143/AR (PDF) | Mar 22, 2012 | 71 MJ 60
> U.S. v. Watson | 11-0523/MC (PDF) | Mar 20, 2012 | 71 MJ 54
> U.S. v. King | 11-0583/NA (PDF) | Mar 13, 2012 | 71 MJ 50
> U.S. v. Weeks | 11-0526/AF (PDF) | Mar 12, 2012 | 71 MJ 44
> U.S. v. Stewart | 11-0440/MC (PDF) | Mar 6, 2012 | 71 MJ 38
> U.S. v. Ballan | 11-0413/NA (PDF) | Mar 1, 2012 | 71 MJ 28
> U.S. v. Campbell | 11-0403/AF (PDF) | Mar 1, 2012 | 71 MJ 19
> U.S. v. Bradley | 11-0399/NA (PDF) | Feb 29, 2012 | 71 MJ 13
> U.S. v. Fry* | 11-0396/MC (PDF) | Feb 21, 2012 | 70 MJ 465
> U.S. v. Hayes* | 11-5003/NA (PDF) | Feb 13, 2012 | 70 MJ 454
> U.S. v. Kreutzer* | 11-0231/AR (PDF) | Feb 2, 2012 | 70 MJ 444
> U.S. v. Morrissette* | 11-0282/AR (PDF) | Jan 24, 2012 | 70 MJ 431
> U.S. v. St. Blanc* | 10-0178/AF (PDF) | Jan 20, 2012 | 70 MJ 424
> U.S. v. Winckelmann* | 11-0280/AR (PDF) | Dec 12, 2011 | 70 MJ 403
> U.S. v. Goodman* | 11-0389/AR (PDF) | Dec 8, 2011 | 70 MJ 396
> U.S. v. Pierce* | 11-0239/AR - 11-5004/AR (PDF) | Dec 8, 2011 | 70 MJ 391
> U.S. v. Schumacher* | 11-0257/MC (PDF) | Dec 7, 2011 | 70 MJ 387
* The asterisk indicates that this opinion has been digested into the Opinion Digest Outline. |
Overview Prior to l976, the opinions of the Court and the intermediate courts were published by Lawyers Co-operative Publishing Company in the Court-Martial Reports (C.M.R.). The 50 C.M.R. volumes are accompanied by a two-volume cumulative citator-index. The opinions of the Court from that era also were bound separately in 23 volumes entitled United States Court of Military Appeals (U.S.C.M.A.). Click here for Opinions Digest
United States Court of Appeals for the Armed Forces • 450 E Street, NW Washington, DC 20442-0001 (202) 761-1448 / DSN 763-1448 • (202) 761-4672 fax